==> sdl4gcj-0.0.1.tar.gz: sdl4gcj-0.0.1/src/sdl4gcj/video/PixelFormat_native.cpp <==
#include "sdl4gcj/video/PixelFormat.h"
#include "sdl4gcj/video/Color.h"

#include <gcj/cni.h>
#include <SDL.h>

using namespace sdl4gcj::video;

jbyte 
PixelFormat::getBitsPerPixel ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->BitsPerPixel;
	return result;
}

jbyte 
PixelFormat::getBytesPerPixel ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->BytesPerPixel;
	return result;
}

jbyte 
PixelFormat::getRloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rloss;
	return result;
}

jbyte 
PixelFormat::getGloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gloss;
	return result;
}

jbyte 
PixelFormat::getBloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bloss;
	return result;
}

jbyte 
PixelFormat::getAloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Aloss;
	return result;
}

jbyte 
PixelFormat::getRshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rshift;
	return result;
}

jbyte 
PixelFormat::getGshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gshift;
	return result;
}

jbyte 
PixelFormat::getBshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bshift;
	return result;
}

jbyte 
PixelFormat::getAshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Ashift;
	return result;
}

jint 
PixelFormat::getRmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rmask;
	return result;
}

jint 
PixelFormat::getGmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gmask;
	return result;
}

jint 
PixelFormat::getBmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bmask;
	return result;
}

jint 
PixelFormat::getAmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Amask;
	return result;
}

jint 
PixelFormat::getColorkey ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->colorkey;
	return result;
}

jint 
PixelFormat::getAlpha ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->alpha;
	return result;
}

jint 
PixelFormat::mapRGB (jint red, jint green, jint blue)
{
	jint result = 0;
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;

	result = SDL_MapRGB(nativeFormat, red, green, blue);

	return result;
}

jint 
PixelFormat::mapRGBA (jint red, jint green, jint blue, jint alpha)
{
	jint result = 0;
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;

	result = SDL_MapRGBA(nativeFormat, red, green, blue, alpha);

	return result;
}

jintArray 
PixelFormat::getRGB (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	jintArray result = JvNewIntArray(3);
	jint* rgb = elements(result);
	Uint8 r, g, b;

	SDL_GetRGB((Uint32)pixel, nativeFormat, &r, &g, &b);
	rgb[0] = r;
	rgb[1] = g;
	rgb[2] = b;

	return result;
}

Color* 
PixelFormat::getRGBColor (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	Uint8 r, g, b;

	SDL_GetRGB((Uint32)pixel, nativeFormat, &r, &g, &b);
	Color* color = new Color(r, g, b);

	return color;
}

jintArray 
PixelFormat::getRGBA (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	jintArray result = JvNewIntArray(4);
	jint* rgba = elements(result);
	Uint8 r, g, b, a;

	SDL_GetRGBA((Uint32)pixel, nativeFormat, &r, &g, &b, &a);
	rgba[0] = r;
	rgba[1] = g;
	rgba[2] = b;
	rgba[3] = a;

	return result;
}

Color* 
PixelFormat::getRGBAColor (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	Uint8 r, g, b, a;

	SDL_GetRGBA((Uint32)pixel, nativeFormat, &r, &g, &b, &a);
	Color* color = new Color(r, g, b, a);

	return color;
}

JArray<Color *> *
PixelFormat::getPalette ()
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	JArray<Color *> *palette = NULL;

	if (nativeFormat->palette != NULL)
	{
		int ncolors = nativeFormat->palette->ncolors;
		SDL_Color* nativeColors = nativeFormat->palette->colors;

		palette = (JArray< Color *> *)JvNewObjectArray (ncolors, (&Color::class$), NULL);
		Color** colors = elements(palette);
		for (int i = 0;i < ncolors;i++)
		{
			colors[i] = new Color(nativeColors[i].r,
				nativeColors[i].g, nativeColors[i].b);
		}
	}

	return palette;
}

==> sdl4gcj-0.0.3.tar.gz: sdl4gcj-0.0.3/src/sdl4gcj/video/PixelFormat_native.cpp <==
#include "sdl4gcj/video/PixelFormat.h"
#include "sdl4gcj/video/Color.h"
#include "sdl4gcj/video/Palette.h"

#include <gcj/cni.h>
#include <SDL.h>

using namespace sdl4gcj::video;

jbyte 
PixelFormat::getBitsPerPixel ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->BitsPerPixel;
	return result;
}

jbyte 
PixelFormat::getBytesPerPixel ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->BytesPerPixel;
	return result;
}

jbyte 
PixelFormat::getRloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rloss;
	return result;
}

jbyte 
PixelFormat::getGloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gloss;
	return result;
}

jbyte 
PixelFormat::getBloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bloss;
	return result;
}

jbyte 
PixelFormat::getAloss ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Aloss;
	return result;
}

jbyte 
PixelFormat::getRshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rshift;
	return result;
}

jbyte 
PixelFormat::getGshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gshift;
	return result;
}

jbyte 
PixelFormat::getBshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bshift;
	return result;
}

jbyte 
PixelFormat::getAshift ()
{
	jbyte result = 0;
	result = ((SDL_PixelFormat*)implementation)->Ashift;
	return result;
}

jint 
PixelFormat::getRmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Rmask;
	return result;
}

jint 
PixelFormat::getGmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Gmask;
	return result;
}

jint 
PixelFormat::getBmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Bmask;
	return result;
}

jint 
PixelFormat::getAmask ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->Amask;
	return result;
}

jint 
PixelFormat::getColorkey ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->colorkey;
	return result;
}

jint 
PixelFormat::getAlpha ()
{
	jint result = 0;
	result = ((SDL_PixelFormat*)implementation)->alpha;
	return result;
}

jint 
PixelFormat::mapRGB (jint red, jint green, jint blue)
{
	jint result = 0;
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;

	result = SDL_MapRGB(nativeFormat, red, green, blue);

	return result;
}

jint 
PixelFormat::mapRGBA (jint red, jint green, jint blue, jint alpha)
{
	jint result = 0;
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;

	result = SDL_MapRGBA(nativeFormat, red, green, blue, alpha);

	return result;
}

jintArray 
PixelFormat::getRGB (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	jintArray result = JvNewIntArray(3);
	jint* rgb = elements(result);
	Uint8 r, g, b;

	SDL_GetRGB((Uint32)pixel, nativeFormat, &r, &g, &b);
	rgb[0] = r;
	rgb[1] = g;
	rgb[2] = b;

	return result;
}

Color* 
PixelFormat::getRGBColor (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	Uint8 r, g, b;

	SDL_GetRGB((Uint32)pixel, nativeFormat, &r, &g, &b);
	Color* color = new Color(r, g, b);

	return color;
}

jintArray 
PixelFormat::getRGBA (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	jintArray result = JvNewIntArray(4);
	jint* rgba = elements(result);
	Uint8 r, g, b, a;

	SDL_GetRGBA((Uint32)pixel, nativeFormat, &r, &g, &b, &a);
	rgba[0] = r;
	rgba[1] = g;
	rgba[2] = b;
	rgba[3] = a;

	return result;
}

Color* 
PixelFormat::getRGBAColor (jint pixel)
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	Uint8 r, g, b, a;

	SDL_GetRGBA((Uint32)pixel, nativeFormat, &r, &g, &b, &a);
	Color* color = new Color(r, g, b, a);

	return color;
}

Palette*
PixelFormat::getPalette ()
{
	SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
	Palette* palette = NULL;

	if (nativeFormat->palette != NULL)
	{
		int ncolors = nativeFormat->palette->ncolors;
		SDL_Color* nativeColors = nativeFormat->palette->colors;

		palette = new Palette(ncolors);
		for (int i = 0;i < ncolors;i++)
		{
			palette->setColorAt(i, nativeColors[i].r, 
				nativeColors[i].g, nativeColors[i].b);
		}
	}

	return palette;
}
